==> delphixpy-1.11.20.0.tar.gz: delphixpy-1.11.20.0/delphixpy/v1_11_19/web/service/locale/locale.py <==
#
# Copyright 2023 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "service.locale"
"""
from delphixpy.v1_11_19 import response_validator

def get(engine):
    """
    Retrieve the specified LocaleSettings object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_19.delphix_engine.DelphixEngine`
    :rtype: :py:class:`v1_11_19.web.vo.LocaleSettings`
    """
    url = "/resources/json/delphix/service/locale"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['LocaleSettings'], returns_list=False, raw_result=raw_result)

def set(engine, locale_settings=None):
    """
    Update the specified LocaleSettings object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_19.delphix_engine.DelphixEngine`
    :param locale_settings: Payload object.
    :type locale_settings: :py:class:`v1_11_19.web.vo.LocaleSettings`
    """
    url = "/resources/json/delphix/service/locale"
    response = engine.post(url, locale_settings.to_dict(dirty=True) if locale_settings else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)

==> delphixpy-1.11.26.0.tar.gz: delphixpy-1.11.26.0/delphixpy/v1_4_0/web/service/locale/locale.py <==
#
# Copyright 2023 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "service.locale"
"""
from delphixpy.v1_4_0 import response_validator

def set(engine, locale_settings=None):
    """
    Create a new LocaleSettings object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
    :param locale_settings: Payload object.
    :type locale_settings: :py:class:`v1_4_0.web.vo.LocaleSettings`
    :rtype: ``str``
    """
    url = "/resources/json/delphix/service/locale"
    response = engine.post(url, locale_settings.to_dict(dirty=True) if locale_settings else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)

def get(engine):
    """
    Retrieve the specified LocaleSettings object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
    :rtype: :py:class:`v1_4_0.web.vo.LocaleSettings`
    """
    url = "/resources/json/delphix/service/locale"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['LocaleSettings'], returns_list=False, raw_result=raw_result)
